/****************************************************************/
/* Example 3 from Schneider and Tobias (2014).                  */
/****************************************************************/

/*
This is an example of using the %SCDMixed macro for performing
an influence analysis of the heart rate data from "SAS for Mixed Models"
using the Scaled Cook's Distance meaure of Zhu, Ibrahim, and Cho (2012). 
You should run this sample code from the directory that contains the 
SCDMixed.sas file.

REFERENCES 

Schneider, G. and Tobias, R. D. (2014), "A SAS Macro to Diagnose
    Influential Subjects in Longitudinal Studies," in Proceedings of
    the SAS Global Forum 2014 Conference, Cary, NC: SAS Institute Inc.
URL http://support.sas.com/resources/papers/proceedings14/1461-2014.pdf

Zhu, H., Ibrahim, J. G., and Cho, H. (2012), "Perturbation and
    Scaled Cook's Distance," Annals of Statistics, 40, pp. 785-811.

Littell, R. C., Milliken, G. A., Stroup, W. W., Wolfinger, R. D., and
    Schabenberger, O. (2006), SAS for Mixed 
   Models, 2nd Edition, Cary, NC: SAS Institute Inc. 
*/

%include "SCDMixed.sas";
ods graphics on / reset imagename='HeartRateData';

/*
These statements load in the data used to investigate the effect of a test 
medication versus a standard medication and a placebo on heart rate over the 
course of an hour.
*/

data HR;
   input patient drug$ basehr hr1 hr5 hr15 hr30 hr1h;
   array hra{5} hr1 hr5 hr15 hr30 hr1h;
   do i = 1 to 5;
      if (i = 1) then minute = 1/60;
      else if (i = 2) then minute = 5;
      else if (i = 3) then minute = 15;
      else if (i = 4) then minute = 30;
      else minute = 60;
      time   = minute;
      hours  = minute / 60;
      hours1 = hours;
      HR = hra{i};
      output;
   end;
   drop i hr1 hr5 hr15 hr30 hr1h;
   datalines;
201 placebo   92  76  84 88 96 84
202 test      54  58  60 60 60 64
203 placebo   84  86  82 84 86 82
204 standard  72  72  68 68 78 72
205 test      80  84  84 96 92 72
206 placebo   68  72  68 68 64 62
207 standard 100 104 100 92 92 68
208 standard  60  60  58 56 50 56
209 standard  88 104  88 88 78 84
210 test      92  82  82 76 82 80
211 test      88  80  84 80 80 78
212 placebo  102  86  86 96 86 88
214 standard  84  92 100 88 88 80
215 test     104 100  96 88 92 84
216 standard  92  80  72 64 68 64
217 placebo   92  88  84 76 88 84
218 standard  72  84  78 80 80 76
219 test      72 100  92 84 88 80
220 placebo   80  80  80 78 80 78
221 placebo   72  68  76 72 72 68
222 test      88  88  98 98 96 88
223 test      88  88  96 88 88 80
224 placebo   88  78  84 64 68 64
232 standard  78  72  72 78 80 68
;

/*
/ The following %SCDModel macro defines the mixed model to be fit
/ based on Littell, Stroup, Wolfinger, and Schabenberger (2006)
/---------------------------------------------------------------------*/
   %macro SCDModel(Datam=, Effectm=, Outpm=, nSub=);
      proc mixed data=&Datam method=ml;
         class drug hours &Effectm;
         model hr = drug basehr / noint
            influence(effect=&Effectm est)                  /*Required*/
            covb                                            /*Required*/ 
            outpm=&Outpm;                                   /*Required*/
         repeated hours /type=sp(exp)(hours) sub=&Effectm 
            r=1 to &nSub by 1;                              /*Required*/
   %mend;


/*Calls to SCDMixed Macro*/

   %SCDMixed(Data=HR, 
             Effect=patient, 
             DepVar=hr, 
             Fixed=drug basehr /noint, 
             Class=drug hours patient,  
             PlotVar=hours, 
             PlotPercentile=80,
             TablePercentile=75);


   %SCDMixed(Data=HR, 
             Effect=patient, 
             DepVar=hr, 
             Fixed=drug basehr /noint, 
             Class=drug hours patient, 
             PlotVar=hours, 
             PlotPercentile=100,
             TablePercentile=50,
             HighlightedSub=202 208 216 219);
